@@ -14,14 +14,13 @@ class RequestFailedError(Exception):
         return self.message
 
 
-class AssetIDError(Exception):
+class AtomicIDError(Exception):
     """Exception called when Atomic ID is invalid"""
 
     def __init__(self, asset_id):
         super().__init__(self)
         self.message = (
-            "Atomic ID %s is invalid. The Atomic ID must be a string integer."
-            % asset_id
+            f"Atomic ID {asset_id} is invalid. The Atomic ID must be a string integer."
         )
 
     def __str__(self):
